<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Image_Box extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Image Box', 'interico' ), // Name
			array( 
				'description' => esc_html__( 'Display Services, Pages and other', 'interico') // Description
			)
		);

		add_action( 'admin_enqueue_scripts', array( $this, 'member_upload_assets' ) );

	}

	public function member_upload_assets() {
		wp_enqueue_script('media-upload');
		wp_enqueue_script('thickbox');
		wp_enqueue_script('mfc-media-upload', get_template_directory_uri() . '/inc/widgets/member-media-upload.js', array( 'jquery' )) ;
		wp_enqueue_style('thickbox');
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/

	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['page_id']  = absint( $new_instance['page_id'] );

		$instance['image_box_title']   	 = wp_kses_post( $new_instance['image_box_title'] );
		$instance['image_box_content'] 	 = wp_kses_post( $new_instance['image_box_content'] );
		$instance['image_box_link_text'] = wp_kses_post( $new_instance['image_box_link_text'] );
		$instance['show_link'] 			 = wp_kses_post( $new_instance['show_link'] );
		$instance['image_box_alignment'] = wp_kses_post( $new_instance['image_box_alignment'] );
		$instance['image_size'] 		 = wp_kses_post( $new_instance['image_size'] );
		$instance['service_box_style'] 	 = wp_kses_post( $new_instance['service_box_style'] );
		$instance['image_box_number']    = wp_kses_post( $new_instance['image_box_number'] );
		$instance['image_box_url']  	 = wp_kses_post( $new_instance['image_box_url'] );
		$instance['image_box_image']     = wp_kses_post( $new_instance['image_box_image'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {
		$page_id  = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];

		$image_box_title   		= empty( $instance['image_box_title'] ) ? '' : $instance['image_box_title'];
		$image_box_content 		= empty( $instance['image_box_content'] ) ? '' : $instance['image_box_content'];
		$image_box_link_text	= empty( $instance['image_box_link_text'] ) ? '' : $instance['image_box_link_text'];
		$show_link 				= empty( $instance['show_link'] ) ? '' : $instance['show_link'];
		$image_box_alignment 	= empty( $instance['image_box_alignment'] ) ? '' : $instance['image_box_alignment'];
		$image_size 			= empty( $instance['image_size'] ) ? '' : $instance['image_size'];
		$service_box_style  	= empty( $instance['service_box_style'] ) ? '' : $instance['service_box_style'];
		$image_box_number  		= empty( $instance['image_box_number'] ) ? '' : $instance['image_box_number'];
		$image_box_url  		= empty( $instance['image_box_url'] ) ? '' : $instance['image_box_url'];
		$image_box_image		= empty( $instance['image_box_image'] ) ? '' : $instance['image_box_image'];

		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Select Page to Display', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_title' ) ); ?>"><?php esc_html_e( 'Custom Heading (if empty, uses original page title)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_box_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_title' ) ); ?>" type="text" value="<?php echo esc_attr( $image_box_title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_number' ) ); ?>"><?php esc_html_e( 'Number (vertical)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_box_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_number' ) ); ?>" type="text" value="<?php echo esc_attr( $image_box_number ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_content' ) ); ?>"><?php esc_html_e( 'Content (Optional)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_box_content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_content' ) ); ?>" type="text" value="<?php echo esc_attr( $image_box_content ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'service_box_style' ) ); ?>"><?php esc_html_e( 'Select Icon Box Style', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'service_box_style' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'service_box_style' ) ); ?>">
				<option value="dark" <?php selected( $service_box_style, 'dark' ); ?>><?php esc_html_e( 'Dark', 'interico' ); ?></option>
				<option value="default" <?php selected( $service_box_style, 'default' ); ?>><?php esc_html_e( 'Gray', 'interico' ); ?></option>
				<option value="white" <?php selected( $service_box_style, 'white' ); ?>><?php esc_html_e( 'White with shadow', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_alignment' ) ); ?>"><?php esc_html_e( 'Alignment', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'image_box_alignment' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_alignment' ) ); ?>">
				<option value="default" <?php selected( $image_box_alignment, 'default' ); ?>><?php esc_html_e( 'Default', 'interico' ); ?></option>
				<option value="centered" <?php selected( $image_box_alignment, 'centered' ); ?>><?php esc_html_e( 'Centered', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'show_link' ) ); ?>"><?php esc_html_e( 'Show or hide link', 'interico' ); ?></label> <br>
			<select id="<?php echo esc_attr( $this->get_field_id( 'show_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_link' ) ); ?>">
				<option value="hide" <?php selected( $show_link, 'hide' ); ?>><?php esc_html_e( 'Hide', 'interico' ); ?></option>
				<option value="show" <?php selected( $show_link, 'show' ); ?>><?php esc_html_e( 'Show', 'interico' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_link_text' ) ); ?>"><?php esc_html_e( 'Custom Link Text (if empty, uses original link text)', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_box_link_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_link_text' ) ); ?>" type="text" value="<?php echo esc_attr( $image_box_link_text ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_name( 'image_box_image' ) ); ?>"><?php esc_html_e( 'Custom Image (url):', 'interico' ); ?></label>
			<input name="<?php echo esc_attr( $this->get_field_name( 'image_box_image' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'image_box_image' ) ); ?>" class="widefat" type="text" size="36"  value="<?php echo esc_url( $image_box_image ); ?>" />
			<input class="upload_image_button button button-primary" type="button" value="Select Image" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'image_box_url' ) ); ?>"><?php esc_html_e( 'Custom URL', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'image_box_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image_box_url' ) ); ?>" type="text" value="<?php echo esc_attr( $image_box_url ); ?>" />
		</p>

		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/
	 
	public function widget( $args, $instance ) {

		echo $args['before_widget'];

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Set custom title
		$image_box_title = $instance['image_box_title'];
		// If empty, use default page title
		if ( ! $image_box_title ) :
			$image_box_title = $page['post_title'];
		endif;

		// Set custom content
		$image_box_content = $instance['image_box_content'];
		// If empty, use default excerpt
		if ( ! $image_box_content ) :
			$image_box_content = $page['post_excerpt'];
		endif;

		// Set custom link text
		$image_box_link_text = $instance['image_box_link_text'];
		// If empty, use default link set in customizer
		if ( ! $image_box_link_text ) :
			$image_box_link_text = get_theme_mod( 'tc_read_more_string_service', 'Read More' );
		endif;

		// Set style
		if ( isset( $instance['service_box_style'] ) ) {
			$service_box_style = $instance['service_box_style'];
		} else {
			// If empty, use default style
			$service_box_style = 'default';
		}

		// Set number value
		if ( isset( $instance['image_box_number'] ) ) {
			$image_box_number = $instance['image_box_number'];
		} else {
			// If empty, use default style
			$image_box_number = false;
		}

		// Set link visibility options
		if ( isset( $instance['show_link'] ) ) {
			$show_link = $instance['show_link'];
		} else {
			// If empty, use default style
			$show_link = 'show';
		}

		// Set alignment
		if ( isset( $instance['image_box_alignment'] ) ) {
			$image_box_alignment = $instance['image_box_alignment'];
		} else {
			// If empty, use default alignment
			$image_box_alignment = 'default';
		}

		// Set Custom URL
		if ( isset( $instance['image_box_url'] ) ) {
			$page['url'] = $instance['image_box_url'];
		}
		// If empty, get permalink from page ID
		if ( empty($page['url'] ) ) {
			$page['url'] = get_permalink( $page_id );
		}
		
		if ( isset( $instance['image_box_image'] ) ) {
			$image_box_image = $instance['image_box_image'];
		}
		// If empty, get permalink from page ID
		if ( empty( $image_box_image ) ) {
		
			// Prepare Featured Image srcset
			$service_item_image_id   = get_post_thumbnail_id( $page_id );
			$service_item_image_data = wp_get_attachment_image_src( $service_item_image_id, 'interico-service-vertical-m' );
			$sizes 		  			 = array( 'interico-service-vertical-s', 'interico-service-vertical-l' );

			$page['srcset']			 = interico_img_sizes( $service_item_image_id, $sizes );
			$page['image_url'] 		 = $service_item_image_data[0];

		}

		?>			
		
		<!-- Begin Image box -->
			<div class="content-box service-item alignment-<?php echo esc_attr( $image_box_alignment ); ?> service-box-<?php echo esc_attr( $service_box_style ); ?>">
				<a href="<?php echo esc_url( $page['url'] ); ?>">
					<div class="image-container">
						<?php if ( $image_box_number ): ?>
							<div class="vertical-number-box">
								<span class="vertical-number"><?php echo esc_attr( $image_box_number); ?></span>
							</div>
						<?php endif; ?>
						<div class="arrow-box"><span class="icon-arrow-right"></span></div>
						<?php if ( empty( $image_box_image ) ) : ?>
							<img src="<?php echo esc_url( $service_item_image_data[0] ); ?>" srcset="<?php echo esc_html( $page['srcset'] ); ?>" sizes="(min-width: 781px) 360px, calc(100vw - 30px)" alt="<?php echo esc_attr( $page['post_title'] ); ?>">
						<?php else : ?>
							<img src="<?php echo esc_url( $image_box_image ) ?>" alt="<?php echo esc_attr( $image_box_title ); ?>">
						<?php endif; ?>
					</div>
					<div class="content-box-info">
						<h4 class="box-heading"><?php echo esc_attr( $image_box_title ); ?></h4>
						<?php if ( $image_box_content ) : ?>
							<p><?php echo wp_kses_post( $image_box_content ); ?></p>
						<?php endif; ?>
						<?php if ( $show_link === 'show' ) : ?>
							<div class="btn-read-more"><?php printf( esc_html__( '%s', 'interico' ), $image_box_link_text ); ?></div>
						<?php endif; ?>
					</div>
				</a>
			</div>
		<!-- End Image box  -->	

		<?php

		echo $args['after_widget'];
	}
}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Image_Box" );' ) );
