<?php

// Prevent direct file access
if ( ! defined ( 'ABSPATH' ) ) {
	exit;
}

class Interico_Projects_Slider extends WP_Widget {

	/*--------------------------------------------------*/
	/* Constructor
	/* Specifies the name and description
	/*--------------------------------------------------*/

	public function __construct() {
		parent::__construct(
			false,
			esc_html__( 'Interico: Projects Slider', 'interico' ), // Name
			array(
				'description' => esc_html__( 'Insert Projects Slider', 'interico' ) // Description
			)
		);
	}

	/*--------------------------------------------------*
	 * Sanitize widget data.
	 * @see WP_Widget::update()
	 /*--------------------------------------------------*/
	
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['page_id'] 			    = absint( $new_instance['page_id'] );
		$instance['gallery_button_text']    = wp_kses_post( $new_instance['gallery_button_text'] );
		$instance['gallery_items_count']  = absint( $new_instance['gallery_items_count'] );
		$instance['captions_style']			= wp_kses_post( $new_instance['captions_style'] );

		return $instance;
	}

	/*--------------------------------------------------*
	 * Widget form in the Back End
	 * @see WP_Widget::form()
	 /*--------------------------------------------------*/

	public function form( $instance ) {

		$page_id			   = empty( $instance['page_id'] ) ? 0 : (int) $instance['page_id'];
		$gallery_button_text   = empty( $instance['gallery_button_text'] ) ? '' : $instance['gallery_button_text'];
		$gallery_items_count   = empty( $instance['gallery_items_count'] ) ? 3 : (int) $instance['gallery_items_count'];
		$captions_style		   = empty( $instance['captions_style'] ) ? 'default' : $instance['captions_style'];
		
		?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'gallery_items_count' ) ); ?>"><?php esc_html_e( 'Number of Items to load', 'interico' ); ?>:</label> <br />
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'gallery_items_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'gallery_items_count' ) ); ?>" type="text" value="<?php echo esc_attr( $gallery_items_count ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'captions_style' ) ); ?>"><?php esc_html_e( 'Gallery Item Style', 'interico' ); ?>:</label> <br />
			<select id="<?php echo esc_attr( $this->get_field_id('captions_style') ); ?>" name="<?php echo esc_attr( $this->get_field_name('captions_style') ); ?>" class="widefat" style="width:100%;">
			    <option value="default" <?php selected( $captions_style, 'default' ); ?>><?php esc_html_e( 'Style 1: Captions Middle', 'interico' ); ?></option>
			    <option value="bottom" <?php selected( $captions_style, 'bottom' ); ?>><?php esc_html_e( 'Style 2: Captions Bottom', 'interico' ); ?></option> 
			</select>
		</p>
		
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'page_id' ) ); ?>"><?php esc_html_e( 'Gallery Button Link:', 'interico' ); ?></label><br>
			<?php
				wp_dropdown_pages(
					array(
						'selected' => $page_id,
						'id'       => $this->get_field_id( 'page_id' ),
						'name'     => $this->get_field_name( 'page_id' ),
					)
				);
			?>
		</p>
		<?php
	}

	/*--------------------------------------------------*
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 /*--------------------------------------------------*/

	public function widget( $args, $instance ) {

		echo $args['before_widget'];

		$tc_gallery_color_scheme = get_theme_mod( 'tc_gallery_color_scheme' );

		$page_id = $instance['page_id'];
		if ( $page_id ) :
			$page = (array) get_post( $page_id );
		endif;

		// Set captions style
		if ( isset( $instance['captions_style'] ) ) {
			$gallery_captions_style = $instance['captions_style'];
		} else {
			$gallery_captions_style = 'default';
		}

		// Set items count
		if ( isset( $instance['gallery_items_count'] ) ) {
			$gallery_items_count = $instance['gallery_items_count'];
		} else {
			$gallery_items_count = 99;
		}

		// Set link text
		if ( isset( $instance['gallery_button_text'] ) ) {
			$gallery_button_text = $instance['gallery_button_text'];
		} else {
			$gallery_button_text = false;
		}

		// Get permalink from page ID
		$page['url'] = get_permalink( $page_id );
		
		$projects_query = new WP_Query(
			array(
				'post_type' => 'portfolio',
				'posts_per_page' => $gallery_items_count
				)
			);

		?>

		<!-- Begin Latest Projects -->
		<section class="section-gallery gallery-layout-vertical grid-fluid<?php echo ' ' . 'captions-' . esc_attr( $gallery_captions_style); ?>">

				<div class="wow fadeInUp">

				<div class="container-fluid">
					<div class="row no-gutter">
						<div id="gallery-slider">

						<!-- Display the projects -->
						<?php
							$i = 1;

							if ( $projects_query->have_posts() ) :
								while ( $projects_query->have_posts() ) : $projects_query->the_post();

								$project_number = $i++;
								
								$project_id = get_the_ID();
								$project = (array)get_post( $project_id );

								// Prepare Featured Image srcset
								$project_image_id   = get_post_thumbnail_id();

								// Define thumbnail sizes based on chosen layout
								$project_image_data = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-vertical-xl' );
								$sizes 		  		= array( 'interico-portfolio-vertical-xs', 'interico-portfolio-vertical-s' );

								$project['srcset']		= interico_img_sizes( $project_image_id, $sizes );
								$project['image_url'] 	= $project_image_data[0];

								$termsArray = get_the_terms( $project['ID'], 'portfolio_category' );  // Get the terms for this particular item
								$termsString = ""; // initialize the string that will contain the terms
								foreach ( $termsArray as $term ) { // for each term:
									$termsString .= $term->slug . ' '; // create a string that has all the slugs 
								}
						?>
						
							<!-- Begin project item -->
							<div class="item <?php echo esc_attr( $termsString ); ?>">
								<a href="<?php esc_url( the_permalink() ); ?>" class="portfolio-box image-container">
									<img src="<?php echo esc_url( $project['image_url'] ); ?>" srcset="<?php echo esc_html( $project['srcset'] ); ?>" sizes="(min-width: 781px) 480px, calc(100vw - 30px)" alt="<?php echo esc_attr( $project['post_title'] ); ?>">
									<div class="portfolio-box-caption">
										<div class="portfolio-box-caption-content">
											<span class="vertical-number"><?php echo ( $project_number < 10 ) ? '0' . esc_attr( $project_number) : esc_attr($project_number); ?></span>
											<div class="project-category text-faded">
												<?php echo esc_attr( $termsString ); ?>
											</div>
											<div class="project-name">
												<?php echo esc_attr( $project['post_title'] ); ?>
											</div>
										</div>
									</div>
								</a>
							</div> <!-- End project item -->
						
						
							<?php endwhile;	
							wp_reset_postdata();

						endif; ?>
						</div>

					</div> <!-- End row -->
				</div> <!-- End container -->
			</div> <!-- End #gallery -->

			<?php if( esc_attr( $instance['gallery_button_text'] ) ) : ?>
				<a href="<?php echo esc_url( $page['url'] ); ?>" class="btn-all-projects"><?php printf( esc_html__( '%s', 'interico' ), $gallery_button_text ); ?></a>
			<?php endif; ?>		
		</section> <!-- End Content section -->    

		<?php
		echo $args['after_widget'];
	}

}
add_action( 'widgets_init', create_function( '', 'register_widget( "Interico_Projects_Slider" );' ) );