<?php
/**
 * Template Name: Projects page
 *
 * @package Interico
 */

get_header();
get_template_part( 'template-parts/top-content-area' );

if ( class_exists( 'acf' ) ) {
	$tc_gallery_color_scheme = get_field( 'gallery_color_scheme' );
} else {
	$tc_gallery_color_scheme = 'dark';
}

$gallery_filter_button_text = get_theme_mod( 'tc_gallery_filter_button_text', 'All Projects' );

if ( class_exists( 'acf' ) ) {
	$gallery_columns_count = get_field( 'column_count' );
} else {
	$gallery_columns_count = 3;
}

if ( $gallery_columns_count === 0 || empty( $gallery_columns_count ) ) {
	$gallery_columns_count = 3;
}

$gallery_column_width = 12/$gallery_columns_count;

// Set gallery filters visibility
if ( class_exists( 'acf' ) ) {
	$show_gallery_filters = get_field( 'show_gallery_filters' );
} else {
	$show_gallery_filters = 'yes';
}

// Set image size
if ( class_exists( 'acf' ) ) {
	$image_size = get_field( 'image_size' );
} else {
	$image_size = 'default';
}

// Set layout and grid style
if ( class_exists( 'acf' ) ) {
	$gallery_style = get_field( 'gallery_style' );
} else {
	$gallery_style = 'style-1';
}

if ( 'style-1' === $gallery_style || 'style-5' === $gallery_style ) {
	$gallery_layout = 'wide';
	$gallery_grid_style = 'fluid';
} else {
	$gallery_layout = 'boxed';
	$gallery_grid_style = 'spaced';
}

if ( 'style-6' === $gallery_style || 'style-7' === $gallery_style || 'style-8' === $gallery_style || 'style-9' === $gallery_style ) {
	$gallery_layout = 'wide';
	$gallery_grid_style = 'spaced not-full';
}

if ( class_exists( 'acf' ) ) {
	// Set captions style
	if ( 'style-3' === $gallery_style || 'style-7' === $gallery_style ) {
		$gallery_captions_style = 'cards';
	} elseif ( 'style-4' === $gallery_style || 'style-8' === $gallery_style  ) {
		$gallery_captions_style = 'cards' . ' cards-flat';
	} else {
		$gallery_captions_style = 'default';
	}
} else {
	$gallery_captions_style = 'default';
}

$projects_query = new WP_Query(
	array(
		'post_type' => 'portfolio',
		'posts_per_page' => -1
		)
	);

?>


		<!-- Begin Latest Projects -->
		<section class="section-gallery gallery-layout-<?php echo esc_attr( $gallery_layout ); echo ' ' . 'grid-' . esc_attr( $gallery_grid_style); echo ' ' . 'captions-' . esc_attr( $gallery_captions_style); echo 'light' === esc_attr( $tc_gallery_color_scheme ) ? ' ' . 'gallery-light' : '' ?>">
			<div class="container">
				<div class="row">
					<div class="col-md-12">
						<div class="latest-projects">
							<?php if ( 'yes' === $show_gallery_filters ) : ?>
								<div class="gallery-categories normal">
									<ul id="filters">
									    <li><a href="#" data-filter="*" class="selected"><?php printf( esc_html__( '%s', 'interico' ), $gallery_filter_button_text ); ?></a></li>
										<?php if ( post_type_exists( 'portfolio' ) ) {
											$terms = get_terms( 'portfolio_category' ); // get all categories (terms)
											$count = count( $terms ); // How many terms?
											if ( $count > 0 ){  // If there are more than 0 terms
												foreach ( $terms as $term ) {  // for each term:
													echo "<li><a href='#' data-filter='.".esc_attr( $term->slug )."'>".esc_attr( $term->name )."</a></li>\n";
													//create a list item with the current term slug for sorting, and name for label
												}
											}
										}
										?>
									</ul>
								</div>	
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>

			<?php if ( 'boxed' !== $gallery_layout ) : ?>
				<div class="animated fadeIn" id="gallery">
			<?php endif; ?>

				<div class="container<?php echo 'boxed' !== $gallery_layout ? '-fluid' : '' ?>">
					<div class="row<?php echo 'fluid' === $gallery_grid_style ? ' no-gutter' : '' ?>">

						<?php if ( 'boxed' === $gallery_layout ): ?>
							<div class="animated fadeInUp" id="gallery">
						<?php endif; ?>
					

						<!-- Display the projects -->
						<?php
							if ( $projects_query->have_posts() ) :
								while ( $projects_query->have_posts() ) : $projects_query->the_post();
								
								$project_id = get_the_ID();
								$project = (array)get_post( $project_id );

								// Prepare Featured Image srcset
								$project_image_id   = get_post_thumbnail_id();

								// Define thumbnail sizes based on chosen layout
								if ( 'style-5' === $gallery_style || 'style-7' === $gallery_style || 'style-8' === $gallery_style || 'style-9' === $gallery_style || 'vertical' === $image_size ) {
									$project_image_data = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-vertical-s' );
									$sizes 		  		= array( 'interico-portfolio-vertical-l' );
								} else {
									$project_image_data = wp_get_attachment_image_src( $project_image_id, 'interico-portfolio-m' );
									$sizes 		  		= array( 'interico-portfolio-xs', 'interico-portfolio-s', 'interico-portfolio-ml', 'interico-portfolio-l', 'interico-portfolio-xl', );
								}

								$project['srcset']		= interico_img_sizes( $project_image_id, $sizes );
								$project['image_url'] 	= $project_image_data[0];

								$termsArray = get_the_terms( $project['ID'], 'portfolio_category' );  // Get the terms for this particular item
								$termsString = ""; // initialize the string that will contain the terms
								if ( $termsArray ) {
									foreach ( $termsArray as $term ) { // for each term:
										$termsString .= $term->slug . ' '; // create a string that has all the slugs 
									}
								}
						?>
						
							<!-- Begin project item -->
							<div class="col-xs-12 col-sm-6 col-lg-<?php echo esc_attr( $gallery_column_width ); ?> item <?php echo esc_attr( $termsString ); ?>">
								<a href="<?php esc_url( the_permalink() ); ?>" class="portfolio-box">
									<?php if ( $project['image_url'] ) : ?>
										<div class="image-container">
											<img src="<?php echo esc_url( $project['image_url'] ); ?>" srcset="<?php echo esc_html( $project['srcset'] ); ?>" width="<?php echo esc_attr( $project_image_data[1] ); ?>" height="<?php echo esc_attr( $project_image_data[2] ); ?>" sizes="(min-width: 781px) 600px, calc(100vw - 30px)" alt="<?php echo esc_attr( $project['post_title'] ); ?>">
										</div>
									<?php endif; ?>
									<div class="portfolio-box-caption">
										<div class="portfolio-box-caption-content">
											<div class="project-category text-faded">
												<?php echo esc_attr( str_replace( "-", " ", $termsString) ); ?>
											</div>
											<div class="project-name">
												<?php echo esc_attr( $project['post_title'] ); ?>
											</div>
										</div>
									</div>
								</a>
							</div> <!-- End project item -->
						
							<?php endwhile;
							wp_reset_postdata();

						endif; ?>

					</div> <!-- End row -->

				</div> <!-- End container -->
			</div> <!-- End #gallery -->
		</section> <!-- End Content section -->

		<div class="container">
			<div class="row">

				<!-- Begin page content -->
				<main class="col-xs-12">

					<?php
						while ( have_posts() ) : the_post();

							get_template_part( 'template-parts/content', 'page' );

							// If comments are open or we have at least one comment, load up the comment template.
							if ( comments_open() || get_comments_number() ) :
								comments_template();
							endif;

						endwhile; // End of the loop.
					?>

				</main> <!-- End page content -->

			</div> <!-- End row -->
		</div>



<?php get_footer(); ?>
