<?php
/**
 * The template for displaying top content area right below the header.
 * @package Interico
 */ 

if ( is_home() ) {
	$page_id = absint( get_option( 'page_for_posts' ) );
} elseif ( class_exists( 'Woocommerce' ) && is_woocommerce() ) {
	$page_id = absint( get_option( 'woocommerce_shop_page_id' ) );
} else {
	$page_id = get_the_ID();
}

// Get custom title and background
if ( class_exists( 'acf' ) ) {
	$tca_visibility = get_field( 'show_top_content_area', $page_id );
	$top_content_area_size = get_field( 'top_content_area_size', $page_id );
	$tca_text_alignment = get_field( 'tca_text_alignment', $page_id );
	$title = get_field( 'custom_page_title', $page_id );
	$custom_background_image = get_field( 'title_background_image', $page_id );
	$title_image = $custom_background_image['url'];
	$text_color_scheme = 'white';
	$overlay_color = get_field( 'background_overlay_color', $page_id );
	$overlay_opacity = get_field( 'background_overlay_opacity', $page_id );
	if ( is_singular( 'post' ) ) {
		$layout = get_field( 'post_layout', $page_id );
	} else {
		$layout = get_field( 'layout', $page_id );
	}
	$breadcrumbs = get_field( 'display_breadcrumbs', $page_id );
	if ( $overlay_opacity ) {
		$overlay_opacity = $overlay_opacity/100;
	}
	if ( get_field( 'video_height' ) ) {
		$video_height = get_field( 'video_height' );
	} else {
		$video_height = 800;
	}
}

if ( !isset( $layout ) || 'default' === $layout ) {
	if ( is_singular( 'post' ) ) {
		$layout = get_theme_mod( 'tc_default_post_layout', 'standard' );
	} else {
		$layout = 'default';
	}
}

// Set visibility option
if ( !isset( $tca_visibility ) || 'default' === $tca_visibility ) {
	$tca_visibility = get_theme_mod( 'tc_default_tca_visibility', 'yes');
}

//Set default Top content area size
if ( empty( $top_content_area_size ) || 'default' === $top_content_area_size ) {
	$top_content_area_size = get_theme_mod( 'tc_default_tca_size', 'medium' );
}

//Set default Top content area text alignment
if ( empty( $tca_text_alignment ) || 'default' === $tca_text_alignment ) {
	$tca_text_alignment = get_theme_mod( 'tc_default_tca_text_alignment', 'center' );
}


// Set default text color scheme
if ( !isset( $text_color_scheme ) ) {
	$text_color_scheme = 'white';
}

//Check if custom title background is set
if ( !isset( $title_image ) ) {
	$title_image = get_theme_mod( 'tc_interico_tca_img' );
}

//Check if overlay color is set
if ( !isset( $overlay_color ) || empty( $overlay_color ) ) {
	$overlay_color = get_theme_mod( 'tc_interico_overlay_color', '#444444' );
}

//Check if overlay opacity is set
if ( !isset( $overlay_opacity ) || empty( $overlay_opacity ) ) {
	$overlay_opacity = get_theme_mod( 'tc_interico_overlay_opacity', 30 );
	$overlay_opacity = $overlay_opacity/100;
}

if ( class_exists( 'acf' ) && !empty( $title ) ) {
	$title = get_field( 'custom_page_title', $page_id );
} else {
	if ( is_singular( 'post' ) ) {
		// Retrieve ID from page: blog
		$page_id = absint( get_option( 'page_for_posts' ) );
		$title = get_the_title( $page_id );
		// Reset ID to the posts's ID
		$page_id = get_the_ID();
	} elseif ( is_home() ) {
		$title = get_the_title( $page_id );
	} elseif ( class_exists( 'Woocommerce' ) && is_shop() ) {
		$title = get_the_title( $page_id );
	} elseif ( is_search() ) {
		// Set titles for functional pages: search results, categories, tags, etc.
		$title =  esc_html__( 'Search Results', 'interico' );
	} else if ( is_404() ) {
		$title =  esc_html__( 'Nothing Found', 'interico' );
	} elseif ( is_category() ) {
		$title = esc_html__( 'Category', 'interico') . ': ' . single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = esc_html__( 'Tag', 'interico') . ': ' . single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = esc_html__( 'Articles by', 'interico') . ': ' . get_the_author( '', false );
	} else {
		$title = get_the_title( $page_id );
	}
}

if ( !isset( $breadcrumbs ) || $breadcrumbs === 'default' ) {
	if ( 'no' !== get_theme_mod( 'tc_show_breadcrumbs' ) ) {
		$breadcrumbs = 'display';
	}
}

?>

<?php if ( class_exists( 'acf' ) && 'video' === get_field( 'background_type' ) ) : ?>

	<div class="video-container" style="position: absolute; height: <?php echo esc_attr( $video_height ); ?>px;">

		<?php

		// get video HTML
		$video = get_field( 'video_background' );
		$playlist = get_field( 'video_playlist' );

		// use preg_match to find the src
		preg_match('/src="(.+?)"/', $video, $matches);
		if ( ! isset($matches[1])) {
		   $matches[1] = null;
		}
		$src = $matches[1];

		// add extra params to the src
		$params = array(
		    'controls'  => 0,
		    'hd'        => 1,
		    'autohide'  => 1,
		    'autoplay'	=> 1,
		    'showinfo'  => 0,
		    'loop'		=> 1,
		    'list'		=> $playlist,
		    'mute'		=> 0
		);

		$new_src = add_query_arg($params, $src);

		$video = str_replace($src, $new_src, $video);

		// add extra attributes to iframe html
		$attributes = 'allow="autoplay; encrypted-media" allowfullscreen="" width="1920" frameborder="0"';

		echo str_replace('></iframe>', ' ' . $attributes . '></iframe>', $video);

		?>
		
	</div>

	<!-- Begin Top Content Area -->
	<?php if( 'no' !== $tca_visibility ) : ?>
		<section id="top-content-area" class="with-video-bg" style="height:<?php echo esc_attr( $video_height ); ?>px;">
			<?php if ( $overlay_opacity && $overlay_color ) : ?>
				<div class="overlay" style="opacity: <?php echo esc_attr( $overlay_opacity ); ?>; background-color: <?php echo esc_attr( $overlay_color ); ?>;"></div>
			<?php endif; ?>
			<div class="lines-overlay animated fadeInDown"></div>
			<div class="title-content">

				<?php if( class_exists('acf') && get_field( 'subtitle_header', $page_id ) ) : ?>
					<span class="page-subtitle animated fadeInDown"><?php esc_attr( the_field( 'subtitle_header', $page_id ) ); ?></span>
				<?php endif; ?>
					
				<h1 class="page-title animated fadeInDown"><?php echo esc_attr( $title ); ?></h1>
				
				<?php if( class_exists('acf') && get_field( 'subtitle_body_text', $page_id ) ) : ?>
					<div class="title-content-text animated fadeInUp">	
						<?php esc_attr( the_field( 'subtitle_body_text', $page_id ) ) ; ?>
					</div>
				<?php endif; ?>
			
			</div>

		</section> <!-- End Top Content Area -->
	<?php endif; ?>

<?php else : ?>

	<!-- Begin Top Content Area -->
	<?php if( 'no' !== $tca_visibility ) : ?>
		<section id="top-content-area" class="tca-<?php echo esc_attr( $top_content_area_size ); ?> tca-text-<?php echo esc_attr($tca_text_alignment); ?>" style="background-image: url('<?php echo esc_url( $title_image ); ?>')">
			<?php if ( $overlay_opacity && $overlay_color ) : ?>
				<div class="overlay" style="opacity: <?php echo esc_attr( $overlay_opacity ); ?>; background-color: <?php echo esc_attr( $overlay_color ); ?>;"></div>
			<?php endif; ?>
			<div class="lines-overlay animated fadeInDown"></div>
			<?php if ( $layout !== 'overlapped-2' ) : ?>
				<div class="container">
					<div class="row">
						<div class="col-md-12">
							<div class="title-content">

								<?php if( class_exists('acf') && get_field( 'subtitle_header', $page_id ) ) : ?>
									<span class="page-subtitle animated fadeInDown"><?php esc_attr( the_field( 'subtitle_header', $page_id ) ); ?></span>
								<?php endif; ?>
								
								<h1 class="page-title animated fadeInDown"><?php echo esc_attr( $title ); ?></h1>
								
								<?php if( class_exists('acf') && get_field( 'subtitle_body_text', $page_id ) ) : ?>
									<div class="title-content-text animated fadeInUp">	
										<?php esc_attr( the_field( 'subtitle_body_text', $page_id ) ) ; ?>
									</div>
								<?php endif; ?>
							
							</div>
						</div>
					</div>
				</div>
			<?php endif; ?>

		</section> <!-- End Top Content Area -->
	<?php endif; ?>

<?php endif; ?>

<!-- Begin breadcrumbs -->
<?php if( function_exists('bcn_display') && ! is_front_page() && ! is_page_template( 'page-projects.php' ) && 'portfolio' !== get_post_type() && $layout !== 'overlapped' && $layout !== 'overlapped-2' && $breadcrumbs === 'display' ) : ?>
	<div class="breadcrumbs">
		<div class="container">	
			<?php bcn_display(); ?>
		</div>
	</div>
<?php endif; ?>
<!-- End breadcrumbs -->